﻿using Quartz;
using SqlSugar;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.CallCenter.Calls;
using Hotline.Repository.SqlSugar;
using MapsterMapper;
using XF.Domain.Cache;
using XF.Domain.Repository;
using XingTang.Sdk;

namespace Hotline.Application.Jobs
{
    /// <summary>
    /// 查询通话记录
    /// </summary>
    public class GetCallsJob : IJob, IDisposable
    {
        private readonly IRepository<TrCallRecord> _trcallRepository;
        private readonly IMapper _mapper;
        private readonly ISqlSugarClient _db;

        public GetCallsJob(
            ISugarUnitOfWork<XingTangDbContext> uow,
            IRepository<TrCallRecord> trcallRepository,
            IMapper mapper
            )
        {
            _trcallRepository = trcallRepository;
            _mapper = mapper;
            _db = uow.Db;
        }

        public async Task Execute(IJobExecutionContext context)
        {
            var calls = await _db.Queryable<XingtangCall>()
                .Where(d => !d.IsSync)
                .Take(100)
                .ToListAsync(context.CancellationToken);

            var unsyncCalls = new List<XingtangCall>();
            foreach (var call in calls)
            {
                var rows = _db.Updateable(new XingtangCall
                {
                    Id = call.Id,
                    IsSync = true
                }).ExecuteCommandWithOptLock();
                if (rows > 0)
                    unsyncCalls.Add(call);
            }

            var trCalls = _mapper.Map<ICollection<TrCallRecord>>(unsyncCalls);
            //填充user信息
        }

        /// <summary>Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.</summary>
        public void Dispose()
        {
            throw new NotImplementedException();
        }
    }
}
